==> rewrite-test-5.3.1-sources.jar: org/openrewrite/java/tree/CompilationUnitTest.kt <==
/*
 * Copyright 2020 the original author or authors.
 * <p>
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * https://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.openrewrite.java.tree

import org.assertj.core.api.Assertions.assertThat
import org.junit.jupiter.api.Assertions.assertEquals
import org.junit.jupiter.api.Test
import org.openrewrite.java.JavaParser
import java.nio.file.Paths

interface CompilationUnitTest {

    @Test
    fun newClass(jp: JavaParser) {
        val a = J.CompilationUnit.buildEmptyClass(Paths.get("sourceSet"), "my.org", "MyClass")

        assertThat(a.printTrimmed()).isEqualTo("""
            package my.org;
            
            public class MyClass {
            }
        """.trimIndent())
    }

    @Test
    fun imports(jp: JavaParser) {
        val a = jp.parse("""
            import java.util.List;
            import java.io.*;
            public class A {}
        """)[0]

        assertEquals(2, a.imports.size)
    }

    @Test
    fun classes(jp: JavaParser) {
        val a = jp.parse("""
            public class A {}
            class B{}
        """)[0]

        assertEquals(2, a.classes.size)
    }
    
    @Test
    fun format(jp: JavaParser) {
        val a = """
            /* Comment */
            package a;
            import java.util.List;
            
            public class A { }
        """
        
        assertEquals(a.trimIndent(), jp.parse(a)[0].printTrimmed())
    }
}

==> rewrite-test-6.1.14-sources.jar: org/openrewrite/java/tree/CompilationUnitTest.kt <==
/*
 * Copyright 2020 the original author or authors.
 * <p>
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * https://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.openrewrite.java.tree

import org.assertj.core.api.Assertions.assertThat
import org.junit.jupiter.api.Assertions.assertEquals
import org.junit.jupiter.api.Test
import org.openrewrite.java.JavaParser
import java.net.URI
import java.nio.file.Paths

interface CompilationUnitTest {

    @Test
    fun newClass(jp: JavaParser) {
        val a = J.CompilationUnit.buildEmptyClass(Paths.get("sourceSet"), "my.org", "MyClass")

        assertThat(a.printTrimmed()).isEqualTo("""
            package my.org;
            
            public class MyClass {
            }
        """.trimIndent())
    }

    @Test
    fun sourceSet(jp: JavaParser) {
        val a = J.CompilationUnit.buildEmptyClass(Paths.get("sourceSet"), "my.org", "MyClass")
        assertThat(a.sourceSet.toString()).isEqualTo("sourceSet")
    }

    @Test
    fun imports(jp: JavaParser) {
        val a = jp.parse("""
            import java.util.List;
            import java.io.*;
            public class A {}
        """)[0]

        assertEquals(2, a.imports.size)
    }

    @Test
    fun classes(jp: JavaParser) {
        val a = jp.parse("""
            public class A {}
            class B{}
        """)[0]

        assertEquals(2, a.classes.size)
    }

    @Test
    fun format(jp: JavaParser) {
        val a = """
            /* Comment */
            package a;
            import java.util.List;
            
            public class A { }
        """

        assertEquals(a.trimIndent(), jp.parse(a)[0].printTrimmed())
    }
}
